@@ -742,6 +742,7 @@ sig
   val add: key -> 'a -> 'a t -> 'a t
   val update: key -> key -> 'a -> 'a t -> 'a t
   val find: key -> 'a t -> 'a
+  val find_opt: key -> 'a t -> 'a option
   val find_default: 'a -> key -> 'a t -> 'a
   val remove: key -> 'a t -> 'a t
   val modify: key -> ('a -> 'a) -> 'a t -> 'a t
@@ -816,7 +817,7 @@ struct
   include Map.Make(Ord)
 
   (* We break the abstraction of stdlib's Map module by exposing
-     it's underlyding datatype, which is exactly ((key, 'a)
+     it's underlying datatype, which is exactly ((key, 'a)
      Concrete.map). We therefore have O(1) conversion to and from
      Concrete, which allow us to add new features to the Map
      module while reusing stdlib's implementation (and, in fact,
@@ -841,6 +842,7 @@ struct
   let values t = Concrete.values (impl_of_t t)
   let update k1 k2 v2 t = t_of_impl (Concrete.update k1 k2 v2 Ord.compare (impl_of_t t))
   let find_default d k t = Concrete.find_default d k Ord.compare (impl_of_t t)
+  let find_opt k t = Concrete.find_option k Ord.compare (impl_of_t t)
 
   let of_enum e = t_of_impl (Concrete.of_enum Ord.compare e)
 
@@ -973,6 +975,13 @@ let find x m = Concrete.find x Pervasives.compare m
   empty |> add 2 'y' |> add 1 'x' |> find 2 = 'y'
 *)
 
+let find_opt x m = Concrete.find_option x Pervasives.compare m
+
+(*$T find_opt
+    find_opt  4 (add 1 2 empty) = None
+    find_opt 1 (add 1 2 empty) = Some 2
+*)
+
 let find_default def x m =
   Concrete.find_default def x Pervasives.compare m
 
@@ -1166,6 +1175,9 @@ module PMap = struct (*$< PMap *)
   let find x m =
     Concrete.find x m.cmp m.map
 
+  let find_opt x m =
+    Concrete.find_option x m.cmp m.map
+
   let find_default def x m =
     Concrete.find_default def x m.cmp m.map
 
