@@ -586,16 +586,6 @@ sig
   val print :  ?first:string -> ?last:string -> ?sep:string ->
     ('a BatInnerIO.output -> elt -> unit) ->
     'a BatInnerIO.output -> t -> unit
-  module Infix : sig
-    val (<--) : t -> elt -> t (** insertion *)
-    val (<.) : t -> t -> bool  (** strict subset *)
-    val (>.) : t -> t -> bool  (** strict superset *)
-    val (<=.) : t -> t -> bool (** subset *)
-    val (>=.) : t -> t -> bool (** superset *)
-    val (-.) : t -> t -> t     (** difference *)
-    val (&&.) : t -> t -> t   (** intersection *)
-    val (||.) : t -> t -> t   (** union *)
-  end
   (** Operations on {!Set} without exceptions.*)
   module Exceptionless : sig
     val min_elt: t -> elt option
@@ -727,17 +717,6 @@ struct
   let print ?first ?last ?sep print_elt out t =
     Concrete.print ?first ?last ?sep print_elt out (impl_of_t t)
 
-  module Infix = struct
-    let (<--) s x = add x s
-    let (<.) a b = not (equal a b) && subset a b
-    let (>.) a b = not (equal a b) && subset b a
-    let (<=.) = subset
-    let (>=.) a b = subset b a
-    let (-.) = diff
-    let (&&.) = inter
-    let (||.) = union
-  end
-
   module Exceptionless =
   struct
     let min_elt t = try Some (min_elt t) with Not_found -> None
@@ -845,10 +824,10 @@ module PSet = struct (*$< PSet *)
 
   let max_elt s = Concrete.max_elt s.set
   let enum s = Concrete.enum s.set
-  let of_enum e = { cmp = compare; set = Concrete.of_enum compare e }
+  let of_enum ?(cmp = compare) e = { cmp; set = Concrete.of_enum compare e }
   let of_enum_cmp ~cmp t = { cmp = cmp; set = Concrete.of_enum cmp t }
-  let of_list l = { cmp = compare; set = Concrete.of_list compare l }
-  let of_array a = { cmp = compare; set = Concrete.of_array compare a }
+  let of_list ?(cmp = compare) l = { cmp; set = Concrete.of_list compare l }
+  let of_array ?(cmp = compare) a = { cmp; set = Concrete.of_array compare a }
   let print ?first ?last ?sep print_elt out s =
     Concrete.print ?first ?last ?sep print_elt out s.set
   let for_all f s = Concrete.for_all f s.set
@@ -882,17 +861,6 @@ module PSet = struct (*$< PSet *)
   let equal s1 s2 = Concrete.equal s1.cmp s1.set s2.set
   let subset s1 s2 = Concrete.subset s1.cmp s1.set s2.set
   let disjoint s1 s2 = Concrete.disjoint s1.cmp s1.set s2.set
-
-  module Infix = struct
-    let (<--) s x = add x s
-    let (<.) a b = not (equal a b) && subset a b
-    let (>.) a b = not (equal a b) && subset b a
-    let (<=.) = subset
-    let (>=.) a b = subset b a
-    let (-.) = diff
-    let (&&.) = intersect
-    let (||.) = union
-  end
 end (*$>*)
 
 type 'a t = 'a Concrete.set
@@ -917,7 +885,7 @@ let find x s = Concrete.find Pervasives.compare x s
   let x = "abc" in (find "abc" (singleton x)) == x
   let x = (1,1) in (find (1,1) (singleton x)) == x
   let x,y = (1,1),(1,1) in find x (singleton y) == y
-  let x,y = "a","a" in find x (singleton y) != x
+  let x,y = [|0|],[|0|] in find x (singleton y) != x
   try ignore (find (1,2) (singleton (1,1))); false with Not_found -> true
 *)
 
@@ -1083,17 +1051,6 @@ let disjoint s1 s2 = Concrete.disjoint Pervasives.compare s1 s2
 
 *)
 
-module Infix = struct
-  let (<--) s x = add x s
-  let (<.) a b = not (equal a b) && subset a b
-  let (>.) a b = not (equal a b) && subset b a
-  let (<=.) = subset
-  let (>=.) a b = subset b a
-  let (-.) = diff
-  let (&&.) = intersect
-  let (||.) = union
-end
-
 module Incubator = struct (*$< Incubator *)
   let op_map f s = Concrete.op_map f s
     (*$T op_map
