@@ -301,19 +301,6 @@ sig
     ('a BatInnerIO.output -> elt -> unit) ->
     'a BatInnerIO.output -> t -> unit
 
-  (** {7 Infix operators} *)
-
-  module Infix : sig
-    val (<--) : t -> elt -> t (** insertion *)
-    val (<.) : t -> t -> bool  (** strict subset *)
-    val (>.) : t -> t -> bool  (** strict superset *)
-    val (<=.) : t -> t -> bool (** subset *)
-    val (>=.) : t -> t -> bool (** superset *)
-    val (-.) : t -> t -> t     (** difference *)
-    val (&&.) : t -> t -> t   (** intersection *)
-    val (||.) : t -> t -> t   (** union *)
-  end
-
   (** {6 Override modules}*)
 
   (**
@@ -667,19 +654,6 @@ val print :  ?first:string -> ?last:string -> ?sep:string ->
   ('a BatInnerIO.output -> 'c -> unit) ->
   'a BatInnerIO.output -> 'c t -> unit
 
-(** {7 Infix operators} *)
-
-module Infix : sig
-  val (<--) : 'a t -> 'a -> 'a t (** insertion *)
-  val (<.) : 'a t -> 'a t -> bool  (** strict subset *)
-  val (>.) : 'a t -> 'a t -> bool  (** strict superset *)
-  val (<=.) : 'a t -> 'a t -> bool (** subset *)
-  val (>=.) : 'a t -> 'a t -> bool (** superset *)
-  val (-.) : 'a t -> 'a t -> 'a t     (** difference *)
-  val (&&.) : 'a t -> 'a t -> 'a t   (** intersection *)
-  val (||.) : 'a t -> 'a t -> 'a t   (** union *)
-end
-
 (** {6 Incubator} *)
 module Incubator : sig
 
@@ -937,17 +911,16 @@ module PSet : sig
       The returned enumeration is sorted in increasing order with respect
       to the ordering of this set.*)
 
-  val of_enum: 'a BatEnum.t -> 'a t
+  val of_enum: ?cmp:('a -> 'a -> int) -> 'a BatEnum.t -> 'a t
 
   val of_enum_cmp: cmp:('a -> 'a -> int) -> 'a BatEnum.t -> 'a t
 
-  val of_list: 'a list -> 'a t
+  val of_list: ?cmp:('a -> 'a -> int) -> 'a list -> 'a t
   (** builds a set from the given list, using the default comparison
       function *)
 
-  val of_array: 'a array -> 'a t
-  (** builds a set from the given array, using the default comparison
-      function *)
+  val of_array: ?cmp:('a -> 'a -> int) -> 'a array -> 'a t
+  (** builds a set from the given array and comparison function *)
 
   (** {6 Boilerplate code}*)
 
@@ -958,19 +931,6 @@ module PSet : sig
     ('a BatInnerIO.output -> 'c -> unit) ->
     'a BatInnerIO.output -> 'c t -> unit
 
-  (** {7 Infix operators} *)
-
-  module Infix : sig
-    val (<--) : 'a t -> 'a -> 'a t (** insertion *)
-    val (<.) : 'a t -> 'a t -> bool  (** strict subset *)
-    val (>.) : 'a t -> 'a t -> bool  (** strict superset *)
-    val (<=.) : 'a t -> 'a t -> bool (** subset *)
-    val (>=.) : 'a t -> 'a t -> bool (** superset *)
-    val (-.) : 'a t -> 'a t -> 'a t     (** difference *)
-    val (&&.) : 'a t -> 'a t -> 'a t   (** intersection *)
-    val (||.) : 'a t -> 'a t -> 'a t   (** union *)
-  end
-
   (** get the comparison function used for a polymorphic map *)
   val get_cmp : 'a t -> ('a -> 'a -> int)
 
